@@ -16,6 +16,7 @@ import pickle
 from . import infin_ast
 from datetime import datetime, timedelta
 import time
+import mlflow
 from mlflow import start_run, end_run, log_metric, log_param, log_artifacts, set_experiment, log_artifact, log_param
 from mlflow.tracking.client import MlflowClient
 from mlflow.entities import ViewType
@@ -113,7 +114,7 @@ def get_xform_info(xformname):
         print(f'Other error occurred: {err}')
         raise
     xform = response.json()['transform']
-    if ('dockerfile' in xform):
+    if ('dockerfile' in xform and xform['dockerfile'] != None):
         return xform['xformcode']['S'], xform['dockerfile']['S']
     else:
         return xform['xformcode']['S'], None
@@ -327,7 +328,8 @@ def s3downloader(**kwargs):
                     temp_output_dir = tempfile.mkdtemp()
                     #namespaced_infin_transform_one_object(bucketname, parentdir,\
                     #        filename, tmpf_name, **kwargs)
-                    namespaced_infin_transform_one_object(tmpf_name, temp_output_dir, **kwargs)
+                    namespaced_infin_transform_one_object(tmpf_name, temp_output_dir,\
+                            parentdir, **kwargs)
                 except Exception as e1:
                     status_str = str(e1)
                     info("Error executing infin_transform_one_object_tmpfile: " + status_str)
@@ -641,7 +643,7 @@ def read_and_xform_dir_by_dir(client, bucketname, prefix_in, transform_string, *
 
         namespaced_infin_transform_fnx = namespaced_function(glb[xn], glb, None, True)
         try:
-            namespaced_infin_transform_fnx(temp_input_dir, temp_output_dir, **kwargs)
+            namespaced_infin_transform_fnx(temp_input_dir, temp_output_dir, parentdir, **kwargs)
         except Exception as e:
             status_str = str(e)
             info("Error executing " + xn + ", status=" + status_str)
@@ -1057,11 +1059,14 @@ def run_transforms(transforms):
         transform = transforms[ind]
         run_options = transform['run_options']
 
+        do_reset_mlflow_active_run_stack = False
         do_end_parent_run = False
         if (ind == (len(transforms) - 1)): # last xform
             run_options['last_in_chain_of_xforms'] = 'True'
             if (run_options['run_location'] == 'inline'):
                 do_end_parent_run = True # we end the parent run for inline runs
+            elif (run_options['run_location'] == 'singlevm'):
+                do_reset_mlflow_active_run_stack = True
         else:
             run_options['last_in_chain_of_xforms'] = 'False'
 
@@ -1083,6 +1088,8 @@ def run_transforms(transforms):
             run_id = run_transform(run_options)
         if (do_end_parent_run):
             end_run()
+        if (do_reset_mlflow_active_run_stack):
+            mlflow.tracking.fluent._active_run_stack = []
 
 # returns a pandas DataFrame with index 'YY-MM-dd HH:MM:SS bucketname/filename'
 # and one column named RawBytes that contains the raw bytes from the object
